@@ -42,13 +42,14 @@ class Manager(Gtk.Dialog, Gtk.Buildable):
         drag_icons = ('gnome-mime-application-x-tarz', 'gnome-package', 'package')
         default_export_name = _('Snippets archive') + '.tar.gz'
         dragging = False
-        dnd_target_list = [Gtk.TargetEntry.new('text/uri-list', 0, TARGET_URI)]
 
         def __init__(self):
                 self.snippet = None
                 self._temp_export = None
 
                 self.key_press_id = 0
+                self.dnd_target_list = Gtk.TargetList.new([])
+                self.dnd_target_list.add(Gdk.atom_intern("text/uri-list", True), 0, self.TARGET_URI)
 
         def get_language_snippets(self, path, name = None):
                 library = Library()
@@ -231,11 +232,14 @@ class Manager(Gtk.Dialog, Gtk.Buildable):
                 tv = self.tree_view
 
                 # Set it as a drag source for exporting snippets
-                tv.drag_source_set(Gdk.ModifierType.BUTTON1_MASK, self.dnd_target_list, Gdk.DragAction.DEFAULT | Gdk.DragAction.COPY)
+                tv.drag_source_set(Gdk.ModifierType.BUTTON1_MASK, [], Gdk.DragAction.DEFAULT | Gdk.DragAction.COPY)
+                tv.drag_source_set_target_list(self.dnd_target_list)
 
                 # Set it as a drag destination for importing snippets
                 tv.drag_dest_set(Gtk.DestDefaults.HIGHLIGHT | Gtk.DestDefaults.DROP,
-                                 self.dnd_target_list, Gdk.DragAction.DEFAULT | Gdk.DragAction.COPY)
+                                 [], Gdk.DragAction.DEFAULT | Gdk.DragAction.COPY)
+
+                tv.drag_dest_set_target_list(self.dnd_target_list)
 
                 tv.connect('drag_data_get', self.on_tree_view_drag_data_get)
                 tv.connect('drag_begin', self.on_tree_view_drag_begin)
@@ -511,7 +515,7 @@ class Manager(Gtk.Dialog, Gtk.Buildable):
                         self['entry_tab_trigger'].set_text(self.snippet['tag'])
                         self['entry_accelerator'].set_text( \
                                         self.snippet.accelerator_display())
-                        self['combo_drop_targets'].get_child().set_text(', '.join(self.snippet['drop-targets']))
+                        self['combo_drop_targets'].get_child().set_text(u', '.join(self.snippet['drop-targets']))
 
                         buf = self['source_view_snippet'].get_buffer()
                         buf.begin_not_undoable_action()
@@ -648,7 +652,7 @@ class Manager(Gtk.Dialog, Gtk.Buildable):
 
         def entry_tab_trigger_update_valid(self):
                 entry = self['entry_tab_trigger']
-                text = entry.get_text()
+                text = unicode(entry.get_text(), 'utf-8')
 
                 if text and not Library().valid_tab_trigger(text):
                         img = self['image_tab_trigger']
@@ -671,7 +675,7 @@ class Manager(Gtk.Dialog, Gtk.Buildable):
                 if not self.snippet:
                         return
 
-                text = entry.get_text()
+                text = unicode(entry.get_text(), 'utf-8')
 
                 # save tag
                 self.snippet['tag'] = text
@@ -681,7 +685,7 @@ class Manager(Gtk.Dialog, Gtk.Buildable):
                 if not self.snippet:
                         return
 
-                text = entry.get_text()
+                text = unicode(entry.get_text(), 'utf-8')
 
                 # save drop targets
                 self.snippet['drop-targets'] = text
@@ -695,8 +699,8 @@ class Manager(Gtk.Dialog, Gtk.Buildable):
                         return
 
                 buf = source_view.get_buffer()
-                text = buf.get_text(buf.get_start_iter(), \
-                                buf.get_end_iter(), False)
+                text = unicode(buf.get_text(buf.get_start_iter(), \
+                                buf.get_end_iter(), False), 'utf-8')
 
                 self.snippet['text'] = text
                 self.snippet_changed()
@@ -1105,16 +1109,14 @@ class Manager(Gtk.Dialog, Gtk.Buildable):
                 self.select_iter(piter)
 
         def on_entry_drop_targets_drag_data_received(self, entry, context, x, y, selection_data, info, timestamp):
-                if not Gtk.targets_include_uri(context.targets):
-                        return
-
                 uris = drop_get_uris(selection_data)
-
                 if not uris:
                         return
 
-                if entry.get_text():
-                        mimes = [entry.get_text()]
+                text = unicode(entry.get_text(), 'utf-8')
+
+                if text:
+                        mimes = [text]
                 else:
                         mimes = []
 
@@ -1127,7 +1129,7 @@ class Manager(Gtk.Dialog, Gtk.Buildable):
                         if mime:
                                 mimes.append(mime)
 
-                entry.set_text(', '.join(mimes))
+                entry.set_text(u', '.join(mimes))
                 self.on_entry_drop_targets_focus_out(entry, None)
                 context.finish(True, False, timestamp)
 
